@@ -52,7 +52,7 @@ impl TaskDocs {
             if self.multi {
                 if output.is_dir() {
                     for (i, task) in tasks.iter().filter(|t| !t.hide).enumerate() {
-                        let path = output.join(format!("{}.md", i));
+                        let path = output.join(format!("{i}.md"));
                         file::write(&path, &task.render_markdown(ts, dir)?)?;
                     }
                 } else {
