@@ -1,6 +1,6 @@
 use crate::backend::backend_type::BackendType;
 use crate::config::SETTINGS;
-use crate::registry::{REGISTRY, RegistryTool};
+use crate::registry::{REGISTRY, RegistryTool, tool_enabled};
 use crate::ui::table::MiseTable;
 use eyre::{Result, bail};
 use itertools::Itertools;
@@ -60,7 +60,7 @@ impl Registry {
         let mut table = MiseTable::new(false, &["Tool", "Backends"]);
         let data = REGISTRY
             .iter()
-            .filter(|(short, _)| !SETTINGS.disable_tools.contains(**short))
+            .filter(|(short, _)| filter_enabled(short))
             .filter(|(short, rt)| !self.hide_aliased || **short == rt.short)
             .map(|(short, rt)| (short.to_string(), filter_backend(rt).join(" ")))
             .filter(|(_, backends)| !backends.is_empty())
@@ -76,7 +76,7 @@ impl Registry {
     fn complete(&self) -> Result<()> {
         REGISTRY
             .iter()
-            .filter(|(short, _)| !SETTINGS.disable_tools.contains(**short))
+            .filter(|(short, _)| filter_enabled(short))
             .filter(|(short, rt)| !self.hide_aliased || **short == rt.short)
             .map(|(short, rt)| {
                 (
@@ -110,3 +110,11 @@ static AFTER_LONG_HELP: &str = color_print::cstr!(
     asdf:mise-plugins/mise-poetry
 "#
 );
+
+fn filter_enabled(short: &str) -> bool {
+    tool_enabled(
+        &SETTINGS.enable_tools,
+        &SETTINGS.disable_tools,
+        &short.to_string(),
+    )
+}
