@@ -63,7 +63,7 @@ where
 pub fn new_backend_arg(tool_name: &str) -> BackendArg {
     BackendArg::new_raw(
         tool_name.to_string(),
-        Some(format!("core:{}", tool_name)),
+        Some(format!("core:{tool_name}")),
         tool_name.to_string(),
         None,
     )
