@@ -132,7 +132,7 @@ impl Plugin for VfoxPlugin {
         if !self.plugin_path.exists() {
             let url = self.get_repo_url()?;
             trace!("Cloning vfox plugin: {url}");
-            let pr = mpr.add(&format!("clone vfox plugin {}", url));
+            let pr = mpr.add(&format!("clone vfox plugin {url}"));
             self.repo()
                 .clone(url.as_str(), CloneOptions::default().pr(&pr))?;
         }
