@@ -134,7 +134,7 @@ impl Display for EitherStringOrIntOrBool {
 
 impl Debug for EitherStringOrIntOrBool {
     fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
-        write!(f, "{}", self)
+        write!(f, "{self}")
     }
 }
 
